@theme {
    --animate-toast: translate-left 0.5s ease-in-out;
    @keyframes translate-left {
        0% {
            transform: translate(100%);
        }
        100% {
            transform: translate(0%);
        }
    }
}
