import Alpine from "alpinejs";
import morph from '@alpinejs/morph'
import focus from '@alpinejs/focus'
import alpineManager from "@cpcreation/serenity-front-bundle/js/alpineManager.js";
import { selectValue, formReset} from '@cpcreation/serenity-core-bundle/js/alpineUxLive';
import '@cpcreation/serenity-core-bundle/js/livePatch-alpine';
import stimulusManager from "@cpcreation/serenity-core-bundle/js/stimulusManager.js";
import {Alert} from "tailwindcss-stimulus-components";
import "./css/style.scss";
stimulusManager.register("alert", Alert);
window.selectValue = selectValue;
window.formReset = formReset;
Alpine.plugin(morph);
Alpine.plugin(focus);
alpineManager.registerAll();
window.Alpine = Alpine;
Alpine.start();

